# Partial Datelist

In Drupal 7 website administrators could determine which portions of a date
or datetime dropdown would be collected from the user: the default was
to collect all parts of a date (year, month, date) or datetime (year, month,
day, hour, minute, second).

The option to hide the dropdown list collecting the day, or month and day for
a date is not available anymore in core when configuring a date or datetime
field.

Sometimes all an administrator needs is to collect the year only, not the
exact date. This module comes in handy in these situations, and provides the
option to hide any of the dropdown lists associated with collecting a date.

This module can only interfere with the `Select list` widget, not the calendar
widget (`Date and time`).

Once the administrator chooses the dropdown as its preferred date collection
strategy, the ability to interactively hide any of the combos collecting parts
of a date are activated in the field widget configuration interface.

The portions of the date picker selected to be hidden will not be displayed in
the associated entity edit interface.

## Features

- Hide specific date parts: **Year**, **Month**, **Day**.
- Hide specific time parts: **Hour**, **Minute**, **Second**.
- Works with both `datetime` and `daterange` fields.
- Seamless integration with the field widget configuration interface.
- Changes are reflected in the node add/edit forms.

## Table of contents

- [Installation](#installation)
- [Configuration](#configuration)
  - [Configuring Partial Datelist](#configuring-partial-datelist)
  - [Example Use Case](#example-use-case)
- [Maintainer](#maintainer)
- [Change Log](#change-log)

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

### Configuring Partial Datelist

- Navigate to the Manage Form Display page for the content type where you want to use the `Select list widget`:
  - Example: `/admin/structure/types/manage/[content-type]/form-display`.
- Locate the Date or Datetime field you want to configure.
- Set the widget type to `Select list`. Note that the date type `Timestamp` based on UNIX timestamp storage is not targeted by this module because it does not provide a select list widget.
- Click the Edit button for the widget to open its configuration settings.
- In the `Date list visibility settings` section, you will see checkboxes for each date or datetime part:
  - **Year**, **Month**, **Day** when you selected date type `Date only`.
  - **Year**, **Month**, **Day**, **Hour**, **Minute**, **Second** when you selected date type `Date and time`.
- Check the boxes for the parts you want to hide. For example:
  - To collect only the year, check **Month**, **Day**, **Hour**, **Minute**, and **Second**.
- Save the widget configuration.

### Example Use Case

#### Scenario: Collecting Only the Year

- Field Type: `datetime`
- Widget: `Select list`
- Configuration:
  - Check **Month**, **Day**, **Hour**, **Minute**, and **Second** in the Date list visibility settings.
- Result: The node add/edit form will display a dropdown for the year only.

#### Scenario: Collecting Month and Year

- Field Type: `datetime`
- Widget: `Select list`
- Configuration:
  - Check Day, Hour, Minute, and Second in the Date list visibility settings.
- Result: The node add/edit form will display dropdowns for the month and year.

## Maintainer

- Marcos Buarque de Hollanda [mabho](https://www.drupal.org/u/mabho)

## Change log

- 2025-05-13 - The README file was updated with an extended text and more information on the module's operation and configuration.
- 2025-05-12 - The module is adding Functional Tests to ensure the functionality delivered so far remains consistent whenever new functionality or code updates or fixes are incorporated into the project.
